source("plotProzess.r")

#-----------------
# Input-Parameter:
#
# n         Laenge der Markov-Kette
# P         Uebergangsmatrix (muss quadratisch sein)
#           Dimension von P bestimmt Zustandsraum S = {1,...,k}
# start     Startverteilung (Gleichverteilung per Default)
# plot      Plot-Parameter fuer Visualisierung des Pfades
# ...       Weitere Parameter zum Visualisieren

#-----------------
# Output:
# data.frame mit zwei Spalten fuer Zeitpunkte und Pfad

markovkette <- function(n = 10, P = matrix(rep(0.5, 4), ncol = 2), 
                        start = rep(1/nrow(P), nrow(P)), plot = TRUE, ...)	{
  # Abfangen von ungueltigen Parametereingaben
  # Ist P eine Matrix?
  if(!is.matrix(P)) {
    stop("\u00DCbergangsw'keiten m\u00FCssen in einer Matrix angegeben werden!\n")
  }
  # Ist P quadratisch?
  if(nrow(P) != ncol(P)) {
    stop("\u00DCbergangsmatrix muss quadratisch sein!\n")
  }
  # Sind alle Zeilensummen 1?
  if(!isTRUE(all.equal(rowSums(P), rep(1, nrow(P)), check.attributes = FALSE))) {
    stop("Zeilensummen in der \u00DCbergangsmatrix falsch!\n")
  }
  # Passt die Dimension der Startverteilung zur Uebergangsmatrix? 
  if(length(start) != nrow(P)) {
    stop("Die Startverteilung passt nicht zur \u00DCbergangsmatrix")
  }
  
  # k als Dimension der Uebergangsmatrix zuweisen    
  k <- nrow(P)
  
  # Pfad der Laenge n fuer Markovkette initialisieren
  pfad <- rep(0, n + 1)
  
  # Zufaelliger Startwert fuer die Markovkette aus diskreter Gleichverteilung
  pfad[1] <- sample(k, size = 1, prob = start)
  
  # Markovkette mit zustandsabhaengigen Wahrscheinlichkeiten simulieren
  for(i in 1:n){
    pfad[i + 1] <- sample(k, size = 1, prob = P[pfad[i], ])
  }
  
  # Zusammenfuegen von Zeitpunkten und Pfad in einer Datenmatrix
  mk <- data.frame(zeit = 0:n, pfad = pfad)
  
  # Visualisieren des Pfades, falls Parameter plot==TRUE
  if(plot) {
    # Einzeichnen der Treppenfunktion
    plotProzess(mk$zeit, mk$pfad, xlab = "t", ylab = expression(X[t]),
                yaxt = 'n', ...)
    # Schoenere y-Achsen Labels und Ticks
    axis(side = 2, at = 1:k, cex.axis = 1.2, las = 1)
    # Objektrueckgabe unsichtbar
    return(invisible(mk))
  } else {
    # Objektrueckgabe sichtbar
    return(mk)
  }
}
