#============================================================
# Funktion zu Plotten eines Prozess (Treppenfunktion)
#============================================================

#------------------
# Input-Parameter:
#
# t           Zeitachse
# pfad        Pfad des Prozesses
# verticals   Boolean, sollen vertikale Linien an 
#             den Sprungstellen gezeichnet werden?
# left        Was soll an den linken Enden gezeichnet werden?
#             * NULL:   Nichts (default)
#             * FALSE:  Leere Punkt
#             * TRUE:   Ausgefuellter Punkt
# right       Was soll an den rechten Enden gezeichnet werden?
#             Fuer moegliche Werte siehe 'left'
# xlab, ylab, Uebliche Grafik Paramter fuer plot Funktion
# xlim, ylim, (per Default alle NULL ausser cex.lab = 1.2)
# main,
# cex.lab
# ...         Weitere Grafik-Parameter

plotProzess <- function(t, pfad, verticals = TRUE, left = NULL, right = NULL,
                        xlim = NULL, xlab = NULL, ylim = NULL, ylab = NULL,
                        main = NULL, cex.lab = 1.2, ...) {
  plot(t, pfad, type = "n", xlim = xlim, xlab = xlab, 
       ylim = ylim, ylab = ylab, cex.lab = cex.lab, main = main, ...)
  # Laenge des Prozesses bestimmen
  n <- length(t)
  # Jetzt kommen die Linien rein
  segments(t[-n], pfad[-n], t[-1], pfad[-n], lty = "solid", ...)
  # Nur wenn gewuenscht die vertikalen Linien (ahmt type='s' nach)
  if(verticals) {
    segments(t[-c(1, n)], pfad[-c(n -1, n)], 
             t[-c(1, n)], pfad[-c(1, n)], lty = "dotted", ...)
    
  }
  if(is.logical(left)) {
    # Einzeichnen der linken Endpunkte
    points(t[-c(1, n)], pfad[-c(1, n)], pch = ifelse(left, 16, 21),
           bg = ifelse(left, NA, "white"))
  }
  if(is.logical(right)) {
    # Einzeichnen der rechten Endpunkte
    points(t[-c(1, n)], pfad[-c(n-1, n)], pch = ifelse(right, 16, 21),
           bg = ifelse(right, NA, "white"))
  }
  invisible(NULL)
}